"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
exports.cliArguments = exports.cliUsage = void 0;
var command_line_usage_1 = __importDefault(require("command-line-usage"));
var command_line_args_1 = __importDefault(require("command-line-args"));
var command_line_docs_1 = __importDefault(require("command-line-docs"));
var projectName = "TS compile checker";
var projectDescription = "Validating compilation of multiple TS projects";
var optionDefinitions = [
    {
        name: "help",
        description: "Display this usage guide.",
        alias: "h",
        defaultValue: false,
        type: Boolean
    },
    {
        name: "skip",
        description: "Skipping the installation process.",
        alias: "s",
        defaultValue: false,
        type: Boolean
    },
    {
        name: "include",
        description: "Pass your own set of project paths. This will skip the search process.",
        alias: "i",
        multiple: true,
        defaultValue: [],
        type: String
    },
    {
        name: "exclude",
        description: "Excluding a set of project paths.",
        alias: "e",
        multiple: true,
        defaultValue: [],
        type: String
    },
    {
        name: "options",
        description: 'Override the default options `["--noEmit", "--pretty"]` passed to the tsc compiler for each sub-project',
        alias: "o",
        multiple: true,
        defaultValue: ["--noEmit", "--pretty"],
        type: String
    },
    {
        name: "cwd",
        description: "Current working directory that the search process should be based on. Default directory is `.`.",
        alias: "c",
        defaultValue: ".",
        type: String
    },
    {
        name: "version",
        description: "Current version of the project.",
        alias: "v",
        defaultValue: false,
        type: Boolean
    },
];
if (process.argv.includes("docs")) {
    var cliMarkdownDocs = command_line_docs_1["default"]({
        name: projectName,
        description: projectDescription,
        options: optionDefinitions
    });
    console.log(cliMarkdownDocs);
    process.exit();
}
exports.cliUsage = command_line_usage_1["default"]([
    {
        header: projectName,
        content: projectDescription
    },
    {
        header: "Options",
        optionList: optionDefinitions
    },
    {
        content: "Project home: {underline https://github.com/matis-dk/ts-compile-checker}"
    },
]);
exports.cliArguments = command_line_args_1["default"](optionDefinitions);
